Structs
- Backup
Engine - Backup
Engine Info - Represents information of a backup including timestamp of the backup and the size (please note that sum of all backups’ sizes is bigger than the actual size of the backup directory because some data is shared by multiple backups). Backups are identified by their always-increasing IDs.
- Backup
Engine Options - Create
Backup Options - Options for a single call to
BackupEngine::create_new_backup_with_optionsorBackupEngine::create_new_backup_with_metadata. - Restore
Options - Share
Files Naming - Naming scheme for table and blob files in the
shared_checksumdirectory.
Enums
- CpuPriority
- CPU priority for the background threads that copy files during a backup.
- Restore
Mode - How much of the destination database a restore may reuse.