#[repr(u8)]pub enum BottommostLevelCompaction {
Skip = 0,
IfHaveCompactionFilter = 1,
Force = 2,
ForceOptimized = 3,
}Variants
Skip = 0
Skip bottommost level compaction
IfHaveCompactionFilter = 1
Only compact bottommost level if there is a compaction filter This is the default option
Force = 2
Always compact bottommost level
ForceOptimized = 3
Always compact bottommost level but in bottommost level avoid double-compacting files created in the same compaction