Enum rust_rocksdb::statistics::Ticker

source ·
#[repr(u32)]
pub enum Ticker {
Show 211 variants BlockCacheMiss = 0, BlockCacheHit = 1, BlockCacheAdd = 2, BlockCacheAddFailures = 3, BlockCacheIndexMiss = 4, BlockCacheIndexHit = 5, BlockCacheIndexAdd = 6, BlockCacheIndexBytesInsert = 7, BlockCacheFilterMiss = 8, BlockCacheFilterHit = 9, BlockCacheFilterAdd = 10, BlockCacheFilterBytesInsert = 11, BlockCacheDataMiss = 12, BlockCacheDataHit = 13, BlockCacheDataAdd = 14, BlockCacheDataBytesInsert = 15, BlockCacheBytesRead = 16, BlockCacheBytesWrite = 17, BlockCacheCompressionDictMiss = 18, BlockCacheCompressionDictHit = 19, BlockCacheCompressionDictAdd = 20, BlockCacheCompressionDictBytesInsert = 21, BlockCacheAddRedundant = 22, BlockCacheIndexAddRedundant = 23, BlockCacheFilterAddRedundant = 24, BlockCacheDataAddRedundant = 25, BlockCacheCompressionDictAddRedundant = 26, SecondaryCacheHits = 27, SecondaryCacheFilterHits = 28, SecondaryCacheIndexHits = 29, SecondaryCacheDataHits = 30, CompressedSecondaryCacheDummyHits = 31, CompressedSecondaryCacheHits = 32, CompressedSecondaryCachePromotions = 33, CompressedSecondaryCachePromotionSkips = 34, BloomFilterUseful = 35, BloomFilterFullPositive = 36, BloomFilterFullTruePositive = 37, BloomFilterPrefixChecked = 38, BloomFilterPrefixUseful = 39, BloomFilterPrefixTruePositive = 40, PersistentCacheHit = 41, PersistentCacheMiss = 42, SimBlockCacheHit = 43, SimBlockCacheMiss = 44, MemtableHit = 45, MemtableMiss = 46, GetHitL0 = 47, GetHitL1 = 48, GetHitL2AndUp = 49, CompactionKeyDropNewerEntry = 50, CompactionKeyDropObsolete = 51, CompactionKeyDropRangeDel = 52, CompactionKeyDropUser = 53, CompactionRangeDelDropObsolete = 54, CompactionOptimizedDelDropObsolete = 55, CompactionCancelled = 56, NumberKeysWritten = 57, NumberKeysRead = 58, NumberKeysUpdated = 59, BytesWritten = 60, BytesRead = 61, NumberDbSeek = 62, NumberDbNext = 63, NumberDbPrev = 64, NumberDbSeekFound = 65, NumberDbNextFound = 66, NumberDbPrevFound = 67, IterBytesRead = 68, NumberIterSkip = 69, NumberOfReseeksInIteration = 70, NoIteratorCreated = 71, NoIteratorDeleted = 72, NoFileOpens = 73, NoFileErrors = 74, StallMicros = 75, DbMutexWaitMicros = 76, NumberMultigetCalls = 77, NumberMultigetKeysRead = 78, NumberMultigetBytesRead = 79, NumberMultigetKeysFound = 80, NumberMergeFailures = 81, GetUpdatesSinceCalls = 82, WalFileSynced = 83, WalFileBytes = 84, WriteDoneBySelf = 85, WriteDoneByOther = 86, WriteWithWal = 87, CompactReadBytes = 88, CompactWriteBytes = 89, FlushWriteBytes = 90, CompactReadBytesMarked = 91, CompactReadBytesPeriodic = 92, CompactReadBytesTtl = 93, CompactWriteBytesMarked = 94, CompactWriteBytesPeriodic = 95, CompactWriteBytesTtl = 96, NumberDirectLoadTableProperties = 97, NumberSuperversionAcquires = 98, NumberSuperversionReleases = 99, NumberSuperversionCleanups = 100, NumberBlockCompressed = 101, NumberBlockDecompressed = 102, BytesCompressedFrom = 103, BytesCompressedTo = 104, BytesCompressionBypassed = 105, BytesCompressionRejected = 106, NumberBlockCompressionBypassed = 107, NumberBlockCompressionRejected = 108, BytesDecompressedFrom = 109, BytesDecompressedTo = 110, MergeOperationTotalTime = 111, FilterOperationTotalTime = 112, CompactionCpuTotalTime = 113, RowCacheHit = 114, RowCacheMiss = 115, ReadAmpEstimateUsefulBytes = 116, ReadAmpTotalReadBytes = 117, NumberRateLimiterDrains = 118, BlobDbNumPut = 119, BlobDbNumWrite = 120, BlobDbNumGet = 121, BlobDbNumMultiget = 122, BlobDbNumSeek = 123, BlobDbNumNext = 124, BlobDbNumPrev = 125, BlobDbNumKeysWritten = 126, BlobDbNumKeysRead = 127, BlobDbBytesWritten = 128, BlobDbBytesRead = 129, BlobDbWriteInlined = 130, BlobDbWriteInlinedTtl = 131, BlobDbWriteBlob = 132, BlobDbWriteBlobTtl = 133, BlobDbBlobFileBytesWritten = 134, BlobDbBlobFileBytesRead = 135, BlobDbBlobFileSynced = 136, BlobDbBlobIndexExpiredCount = 137, BlobDbBlobIndexExpiredSize = 138, BlobDbBlobIndexEvictedCount = 139, BlobDbBlobIndexEvictedSize = 140, BlobDbGcNumFiles = 141, BlobDbGcNumNewFiles = 142, BlobDbGcFailures = 143, BlobDbGcNumKeysRelocated = 144, BlobDbGcBytesRelocated = 145, BlobDbFifoNumFilesEvicted = 146, BlobDbFifoNumKeysEvicted = 147, BlobDbFifoBytesEvicted = 148, BlobDbCacheMiss = 149, BlobDbCacheHit = 150, BlobDbCacheAdd = 151, BlobDbCacheAddFailures = 152, BlobDbCacheBytesRead = 153, BlobDbCacheBytesWrite = 154, TxnPrepareMutexOverhead = 155, TxnOldCommitMapMutexOverhead = 156, TxnDuplicateKeyOverhead = 157, TxnSnapshotMutexOverhead = 158, TxnGetTryAgain = 159, FilesMarkedTrash = 160, FilesDeletedFromTrashQueue = 161, FilesDeletedImmediately = 162, ErrorHandlerBgErrorCount = 163, ErrorHandlerBgIoErrorCount = 164, ErrorHandlerBgRetryableIoErrorCount = 165, ErrorHandlerAutoResumeCount = 166, ErrorHandlerAutoResumeRetryTotalCount = 167, ErrorHandlerAutoResumeSuccessCount = 168, MemtablePayloadBytesAtFlush = 169, MemtableGarbageBytesAtFlush = 170, VerifyChecksumReadBytes = 171, BackupReadBytes = 172, BackupWriteBytes = 173, RemoteCompactReadBytes = 174, RemoteCompactWriteBytes = 175, HotFileReadBytes = 176, WarmFileReadBytes = 177, ColdFileReadBytes = 178, HotFileReadCount = 179, WarmFileReadCount = 180, ColdFileReadCount = 181, LastLevelReadBytes = 182, LastLevelReadCount = 183, NonLastLevelReadBytes = 184, NonLastLevelReadCount = 185, LastLevelSeekFiltered = 186, LastLevelSeekFilterMatch = 187, LastLevelSeekData = 188, LastLevelSeekDataUsefulNoFilter = 189, LastLevelSeekDataUsefulFilterMatch = 190, NonLastLevelSeekFiltered = 191, NonLastLevelSeekFilterMatch = 192, NonLastLevelSeekData = 193, NonLastLevelSeekDataUsefulNoFilter = 194, NonLastLevelSeekDataUsefulFilterMatch = 195, BlockChecksumComputeCount = 196, BlockChecksumMismatchCount = 197, MultigetCoroutineCount = 198, ReadAsyncMicros = 199, AsyncReadErrorCount = 200, TableOpenPrefetchTailMiss = 201, TableOpenPrefetchTailHit = 202, TimestampFilterTableChecked = 203, TimestampFilterTableFiltered = 204, ReadAheadTrimmed = 205, FifoMaxSizeCompactions = 206, FifoTtlCompactions = 207, PrefetchBytes = 208, PrefetchBytesUseful = 209, PrefetchHits = 210,
}

Variants



BlockCacheMiss = 0

total block cache misses REQUIRES: BlockCacheMiss == BlockCacheIndexMiss + BlockCacheFilterMiss + BlockCacheDataMiss;



BlockCacheHit = 1

total block cache hit REQUIRES: BlockCacheHit == BlockCacheIndexHit + BlockCacheFilterHit + BlockCacheDataHit;



BlockCacheAdd = 2

of blocks added to block cache.



BlockCacheAddFailures = 3

of failures when adding blocks to block cache.



BlockCacheIndexMiss = 4

of times cache miss when accessing index block from block cache.



BlockCacheIndexHit = 5

of times cache hit when accessing index block from block cache.



BlockCacheIndexAdd = 6

of index blocks added to block cache.



BlockCacheIndexBytesInsert = 7

of bytes of index blocks inserted into cache



BlockCacheFilterMiss = 8

of times cache miss when accessing filter block from block cache.



BlockCacheFilterHit = 9

of times cache hit when accessing filter block from block cache.



BlockCacheFilterAdd = 10

of filter blocks added to block cache.



BlockCacheFilterBytesInsert = 11

of bytes of bloom filter blocks inserted into cache



BlockCacheDataMiss = 12

of times cache miss when accessing data block from block cache.



BlockCacheDataHit = 13

of times cache hit when accessing data block from block cache.



BlockCacheDataAdd = 14

of data blocks added to block cache.



BlockCacheDataBytesInsert = 15

of bytes of data blocks inserted into cache



BlockCacheBytesRead = 16

of bytes read from cache.



BlockCacheBytesWrite = 17

of bytes written into cache.



BlockCacheCompressionDictMiss = 18



BlockCacheCompressionDictHit = 19



BlockCacheCompressionDictAdd = 20



BlockCacheCompressionDictBytesInsert = 21



BlockCacheAddRedundant = 22

of blocks redundantly inserted into block cache.

REQUIRES: BlockCacheAddRedundant <= BlockCacheAdd



BlockCacheIndexAddRedundant = 23

of index blocks redundantly inserted into block cache.

REQUIRES: BlockCacheIndexAddRedundant <= BlockCacheIndexAdd



BlockCacheFilterAddRedundant = 24

of filter blocks redundantly inserted into block cache.

REQUIRES: BlockCacheFilterAddRedundant <= BlockCacheFilterAdd



BlockCacheDataAddRedundant = 25

of data blocks redundantly inserted into block cache.

REQUIRES: BlockCacheDataAddRedundant <= BlockCacheDataAdd



BlockCacheCompressionDictAddRedundant = 26

of dict blocks redundantly inserted into block cache.

REQUIRES: BlockCacheCompressionDictAddRedundant <= BlockCacheCompressionDictAdd



SecondaryCacheHits = 27

Secondary cache statistics



SecondaryCacheFilterHits = 28

Fine grained secondary cache stats



SecondaryCacheIndexHits = 29



SecondaryCacheDataHits = 30



CompressedSecondaryCacheDummyHits = 31

Compressed secondary cache related stats



CompressedSecondaryCacheHits = 32



CompressedSecondaryCachePromotions = 33



CompressedSecondaryCachePromotionSkips = 34



BloomFilterUseful = 35

of times bloom filter has avoided file reads, i.e., negatives.



BloomFilterFullPositive = 36

of times bloom FullFilter has not avoided the reads.



BloomFilterFullTruePositive = 37

of times bloom FullFilter has not avoided the reads and data actually

exist.



BloomFilterPrefixChecked = 38

Prefix filter stats when used for point lookups (Get / MultiGet). (For prefix filter stats on iterators, see LEVEL_Seek.) Checked: filter was queried



BloomFilterPrefixUseful = 39

Useful: filter returned false so prevented accessing data+index blocks



BloomFilterPrefixTruePositive = 40

True positive: found a key matching the point query. When another key with the same prefix matches, it is considered a false positive by these statistics even though the filter returned a true positive.



PersistentCacheHit = 41

persistent cache hit



PersistentCacheMiss = 42

persistent cache miss



SimBlockCacheHit = 43

total simulation block cache hits



SimBlockCacheMiss = 44

total simulation block cache misses



MemtableHit = 45

of memtable hits.



MemtableMiss = 46

of memtable misses.



GetHitL0 = 47

of Get() queries served by L0



GetHitL1 = 48

of Get() queries served by L1



GetHitL2AndUp = 49

of Get() queries served by L2 and up



CompactionKeyDropNewerEntry = 50

Compaction_KeyDrop* count the reasons for key drop during compaction There are 4 reasons currently.

key was written with a newer value. Also includes keys dropped for range del.



CompactionKeyDropObsolete = 51

The key is obsolete.



CompactionKeyDropRangeDel = 52

key was covered by a range tombstone.



CompactionKeyDropUser = 53

user compaction function has dropped the key.



CompactionRangeDelDropObsolete = 54

all keys in range were deleted.



CompactionOptimizedDelDropObsolete = 55

Deletions obsoleted before bottom level due to file gap optimization.



CompactionCancelled = 56

If a compaction was canceled in sfm to prevent ENOSPC



NumberKeysWritten = 57

Number of keys written to the database via the Put and Write call’s



NumberKeysRead = 58

Number of Keys read,



NumberKeysUpdated = 59

Number keys updated, if inplace update is enabled



BytesWritten = 60

The number of uncompressed bytes issued by DB::Put(), DB::Delete(), DB::Merge(), and DB::Write().



BytesRead = 61

The number of uncompressed bytes read from DB::Get(). It could be either from memtables, cache, or table files. For the number of logical bytes read from DB::MultiGet(), please use NumberMultigetBytesRead.



NumberDbSeek = 62

The number of calls to seek/next/prev



NumberDbNext = 63



NumberDbPrev = 64



NumberDbSeekFound = 65

The number of calls to seek/next/prev that returned data



NumberDbNextFound = 66



NumberDbPrevFound = 67



IterBytesRead = 68

The number of uncompressed bytes read from an iterator. Includes size of key and value.



NumberIterSkip = 69

Number of internal keys skipped by Iterator



NumberOfReseeksInIteration = 70

Number of times we had to reseek inside an iteration to skip over large number of keys with same userkey.



NoIteratorCreated = 71

number of iterators created



NoIteratorDeleted = 72

number of iterators deleted



NoFileOpens = 73



NoFileErrors = 74



StallMicros = 75

Writer has to wait for compaction or flush to finish.



DbMutexWaitMicros = 76

The wait time for db mutex. Disabled by default. To enable it set stats level to kAll



NumberMultigetCalls = 77

Number of MultiGet calls, keys read, and bytes read



NumberMultigetKeysRead = 78



NumberMultigetBytesRead = 79



NumberMultigetKeysFound = 80

Number of keys actually found in MultiGet calls (vs number requested by caller) NumberMultigetKeys_Read gives the number requested by caller



NumberMergeFailures = 81



GetUpdatesSinceCalls = 82

Record the number of calls to GetUpdatesSince. Useful to keep track of transaction log iterator refreshes



WalFileSynced = 83

Number of times WAL sync is done



WalFileBytes = 84

Number of bytes written to WAL



WriteDoneBySelf = 85

Writes can be processed by requesting thread or by the thread at the head of the writers queue.



WriteDoneByOther = 86

Equivalent to writes done for others



WriteWithWal = 87

Number of Write calls that request WAL



CompactReadBytes = 88

Bytes read during compaction



CompactWriteBytes = 89

Bytes written during compaction



FlushWriteBytes = 90

Bytes written during flush



CompactReadBytesMarked = 91

Compaction read and write statistics broken down by CompactionReason



CompactReadBytesPeriodic = 92



CompactReadBytesTtl = 93



CompactWriteBytesMarked = 94



CompactWriteBytesPeriodic = 95



CompactWriteBytesTtl = 96



NumberDirectLoadTableProperties = 97

Number of table’s properties loaded directly from file, without creating table reader object.



NumberSuperversionAcquires = 98



NumberSuperversionReleases = 99



NumberSuperversionCleanups = 100



NumberBlockCompressed = 101

of compressions/decompressions executed



NumberBlockDecompressed = 102



BytesCompressedFrom = 103

Number of input bytes (uncompressed) to compression for SST blocks that are stored compressed.



BytesCompressedTo = 104

Number of output bytes (compressed) from compression for SST blocks that are stored compressed.



BytesCompressionBypassed = 105

Number of uncompressed bytes for SST blocks that are stored uncompressed because compression type is kNoCompression, or some error case caused compression not to run or produce an output. Index blocks are only counted if enable_index_compression is true.



BytesCompressionRejected = 106

Number of input bytes (uncompressed) to compression for SST blocks that are stored uncompressed because the compression result was rejected, either because the ratio was not acceptable (see CompressionOptions::max_compressed_bytes_per_kb) or found invalid by the verify_compression option.



NumberBlockCompressionBypassed = 107

Like BytesCompressionBypassed but counting number of blocks



NumberBlockCompressionRejected = 108

Like BytesCompressionRejected but counting number of blocks



BytesDecompressedFrom = 109

Number of input bytes (compressed) to decompression in reading compressed SST blocks from storage.



BytesDecompressedTo = 110

Number of output bytes (uncompressed) from decompression in reading compressed SST blocks from storage.



MergeOperationTotalTime = 111

Tickers that record cumulative time.



FilterOperationTotalTime = 112



CompactionCpuTotalTime = 113



RowCacheHit = 114

Row cache.



RowCacheMiss = 115



ReadAmpEstimateUsefulBytes = 116

Read amplification statistics. Read amplification can be calculated using this formula (ReadAMP_ToTAL_ReadBytes / Read_AMP_Estimate_UsefulBytes) REQUIRES: ReadOptions::read_amp_bytes_per_bit to be enabled Estimate of total bytes actually used.



ReadAmpTotalReadBytes = 117

Total size of loaded data blocks.



NumberRateLimiterDrains = 118

Number of refill intervals where rate limiter’s bytes are fully consumed.



BlobDbNumPut = 119

BlobDB specific stats

of Put/PutTtl/PutUntil to BlobDB. Only applicable to legacy BlobDB.



BlobDbNumWrite = 120

of Write to BlobDB. Only applicable to legacy BlobDB.



BlobDbNumGet = 121

of Get to BlobDB. Only applicable to legacy BlobDB.



BlobDbNumMultiget = 122

of MultiGet to BlobDB. Only applicable to legacy BlobDB.



BlobDbNumSeek = 123

of Seek/SeekToFirst/SeekToLast/SeekForPrev to BlobDB iterator. Only

applicable to legacy BlobDB.



BlobDbNumNext = 124

of Next to BlobDB iterator. Only applicable to legacy BlobDB.



BlobDbNumPrev = 125

of Prev to BlobDB iterator. Only applicable to legacy BlobDB.



BlobDbNumKeysWritten = 126

of keys written to BlobDB. Only applicable to legacy BlobDB.



BlobDbNumKeysRead = 127

of keys read from BlobDB. Only applicable to legacy BlobDB.



BlobDbBytesWritten = 128

of bytes (key + value) written to BlobDB. Only applicable to legacy

BlobDB.



BlobDbBytesRead = 129

of bytes (keys + value) read from BlobDB. Only applicable to legacy

BlobDB.



BlobDbWriteInlined = 130

of keys written by BlobDB as non-Ttl inlined value. Only applicable to

legacy BlobDB.



BlobDbWriteInlinedTtl = 131

of keys written by BlobDB as Ttl inlined value. Only applicable to legacy

BlobDB.



BlobDbWriteBlob = 132

of keys written by BlobDB as non-Ttl blob value. Only applicable to

legacy BlobDB.



BlobDbWriteBlobTtl = 133

of keys written by BlobDB as Ttl blob value. Only applicable to legacy

BlobDB.



BlobDbBlobFileBytesWritten = 134

of bytes written to blob file.



BlobDbBlobFileBytesRead = 135

of bytes read from blob file.



BlobDbBlobFileSynced = 136

of times a blob files being synced.



BlobDbBlobIndexExpiredCount = 137

of blob index evicted from base DB by BlobDB compaction filter because

of expiration. Only applicable to legacy BlobDB.



BlobDbBlobIndexExpiredSize = 138

size of blob index evicted from base DB by BlobDB compaction filter because of expiration. Only applicable to legacy BlobDB.



BlobDbBlobIndexEvictedCount = 139

of blob index evicted from base DB by BlobDB compaction filter because

of corresponding file deleted. Only applicable to legacy BlobDB.



BlobDbBlobIndexEvictedSize = 140

size of blob index evicted from base DB by BlobDB compaction filter because of corresponding file deleted. Only applicable to legacy BlobDB.



BlobDbGcNumFiles = 141

of blob files that were obsoleted by garbage collection. Only applicable

to legacy BlobDB.



BlobDbGcNumNewFiles = 142

of blob files generated by garbage collection. Only applicable to legacy

BlobDB.



BlobDbGcFailures = 143

of BlobDB garbage collection failures. Only applicable to legacy BlobDB.



BlobDbGcNumKeysRelocated = 144

of keys relocated to new blob file by garbage collection.



BlobDbGcBytesRelocated = 145

of bytes relocated to new blob file by garbage collection.



BlobDbFifoNumFilesEvicted = 146

of blob files evicted because of BlobDB is full. Only applicable to

legacy BlobDB.



BlobDbFifoNumKeysEvicted = 147

of keys in the blob files evicted because of BlobDB is full. Only

applicable to legacy BlobDB.



BlobDbFifoBytesEvicted = 148

of bytes in the blob files evicted because of BlobDB is full. Only

applicable to legacy BlobDB.



BlobDbCacheMiss = 149

Integrated BlobDB specific stats

of times cache miss when accessing blob from blob cache.



BlobDbCacheHit = 150

of times cache hit when accessing blob from blob cache.



BlobDbCacheAdd = 151

of data blocks added to blob cache.



BlobDbCacheAddFailures = 152

of failures when adding blobs to blob cache.



BlobDbCacheBytesRead = 153

of bytes read from blob cache.



BlobDbCacheBytesWrite = 154

of bytes written into blob cache.



TxnPrepareMutexOverhead = 155

These counters indicate a performance issue in WritePrepared transactions. We should not seem them ticking them much.

of times prepare_mutex_ is acquired in the fast path.



TxnOldCommitMapMutexOverhead = 156

of times old_commit_map_mutex_ is acquired in the fast path.



TxnDuplicateKeyOverhead = 157

of times we checked a batch for duplicate keys.



TxnSnapshotMutexOverhead = 158

of times snapshot_mutex_ is acquired in the fast path.



TxnGetTryAgain = 159

of times ::Get returned TryAgain due to expired snapshot seq



FilesMarkedTrash = 160

of files marked as trash by sst file manager and will be deleted

later by background thread.



FilesDeletedFromTrashQueue = 161

of trash files deleted by the background thread from the trash queue.



FilesDeletedImmediately = 162

of files deleted immediately by sst file manager through delete

scheduler.



ErrorHandlerBgErrorCount = 163

The counters for error handler, not that, bg_io_error is the subset of bg_error and bg_retryable_io_error is the subset of bg_io_error.



ErrorHandlerBgIoErrorCount = 164



ErrorHandlerBgRetryableIoErrorCount = 165



ErrorHandlerAutoResumeCount = 166



ErrorHandlerAutoResumeRetryTotalCount = 167



ErrorHandlerAutoResumeSuccessCount = 168



MemtablePayloadBytesAtFlush = 169

Statistics for memtable garbage collection: Raw bytes of data (payload) present on memtable at flush time.



MemtableGarbageBytesAtFlush = 170

Outdated bytes of data present on memtable at flush time.



VerifyChecksumReadBytes = 171

Bytes read by VerifyChecksum() and VerifyFileChecksums() APIs.



BackupReadBytes = 172

Bytes read/written while creating backups



BackupWriteBytes = 173



RemoteCompactReadBytes = 174

Remote compaction read/write statistics



RemoteCompactWriteBytes = 175



HotFileReadBytes = 176

Tiered storage related statistics



WarmFileReadBytes = 177



ColdFileReadBytes = 178



HotFileReadCount = 179



WarmFileReadCount = 180



ColdFileReadCount = 181



LastLevelReadBytes = 182

Last level and non-last level read statistics



LastLevelReadCount = 183



NonLastLevelReadBytes = 184



NonLastLevelReadCount = 185



LastLevelSeekFiltered = 186

Statistics on iterator Seek() (and variants) for each sorted run. I.e. a single user Seek() can result in many sorted run Seek()s. The stats are split between last level and non-last level. Filtered: a filter such as prefix Bloom filter indicate the Seek() would not find anything relevant, so avoided a likely access to data+index blocks.



LastLevelSeekFilterMatch = 187

Filter match: a filter such as prefix Bloom filter was queried but did not filter out the seek.



LastLevelSeekData = 188

At least one data block was accessed for a Seek() (or variant) on a sorted run.



LastLevelSeekDataUsefulNoFilter = 189

At least one value() was accessed for the seek (suggesting it was useful), and no filter such as prefix Bloom was queried.



LastLevelSeekDataUsefulFilterMatch = 190

At least one value() was accessed for the seek (suggesting it was useful), after querying a filter such as prefix Bloom.



NonLastLevelSeekFiltered = 191

The same set of stats, but for non-last level seeks.



NonLastLevelSeekFilterMatch = 192



NonLastLevelSeekData = 193



NonLastLevelSeekDataUsefulNoFilter = 194



NonLastLevelSeekDataUsefulFilterMatch = 195



BlockChecksumComputeCount = 196

Number of block checksum verifications



BlockChecksumMismatchCount = 197

Number of times RocksDB detected a corruption while verifying a block checksum. RocksDB does not remember corruptions that happened during user reads so the same block corruption may be detected multiple times.



MultigetCoroutineCount = 198



ReadAsyncMicros = 199

Time spent in the ReadAsync file system call



AsyncReadErrorCount = 200

Number of errors returned to the async read callback



TableOpenPrefetchTailMiss = 201

Number of lookup into the prefetched tail (see TableOpenPrefetchTailReadBytes) that can’t find its data for table open



TableOpenPrefetchTailHit = 202

Number of lookup into the prefetched tail (see TableOpenPrefetchTailReadBytes) that finds its data for table open



TimestampFilterTableChecked = 203

Statistics on the filtering by user-defined timestamps

of times timestamps are checked on accessing the table



TimestampFilterTableFiltered = 204

of times timestamps can successfully help skip the table access



ReadAheadTrimmed = 205

Number of times readahead is trimmed during scans when ReadOptions.auto_readahead_size is set.



FifoMaxSizeCompactions = 206

Number of Fifo compactions that drop files based on different reasons



FifoTtlCompactions = 207



PrefetchBytes = 208

Number of bytes prefetched during user initiated scan



PrefetchBytesUseful = 209

Number of prefetched bytes that were actually useful



PrefetchHits = 210

Number of FS reads avoided due to scan prefetching

Implementations

source

impl Ticker

source

pub const fn name(&self) -> &'static str

The corresponding rocksdb string identifier for this variant

source

pub fn iter() -> Iter<'static, Ticker>