LruCacheOptions

Struct LruCacheOptions 

pub struct LruCacheOptions { /* private fields */ }

Implementations

Source

impl LruCacheOptions

pub fn set_capacity(&mut self, cap: usize)

Capacity of the cache, in the same units as the charge of each entry. This is typically measured in bytes, but can be a different unit if using kDontChargeCacheMetadata.

pub fn set_num_shard_bits(&mut self, val: c_int)

Cache is sharded into 2^num_shard_bits shards, by hash of key. If < 0, a good default is chosen based on the capacity and the implementation. (Mutex-based implementations are much more reliant on many shards for parallel scalability.)

pub fn set_memory_allocator(&mut self, allocator: &MemoryAllocator)

Allocates cache block memory through allocator instead of the system allocator.

These options do not borrow the allocator. The C setter copies the shared_ptr<MemoryAllocator> out of the handle, so the allocator stays alive through the options and the caches built from them even after the MemoryAllocator here is dropped.