pub trait WriteBatchIteratorCf {
// Required methods
fn put_cf(&mut self, cf_id: u32, key: &[u8], value: &[u8]);
fn delete_cf(&mut self, cf_id: u32, key: &[u8]);
fn merge_cf(&mut self, cf_id: u32, key: &[u8], value: &[u8]);
}Expand description
Receives the puts, deletes, and merges of a write batch with column family information.
This trait extends write batch iteration to support column family-specific operations. The application must implement this trait when iterating operations within a WriteBatch that contains column family-aware writes.
Note that for the default column family “default”, the column family ID is 0.
Required Methods
Sourcefn put_cf(&mut self, cf_id: u32, key: &[u8], value: &[u8])
fn put_cf(&mut self, cf_id: u32, key: &[u8], value: &[u8])
Called with a column family ID, key, and value that were put into the specific column family of the batch.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".