Module backup

Module backup 

Structs

BackupEngine
BackupEngineInfo
Represents information of a backup including timestamp of the backup and the size (please note that sum of all backups’ sizes is bigger than the actual size of the backup directory because some data is shared by multiple backups). Backups are identified by their always-increasing IDs.
BackupEngineOptions
CreateBackupOptions
Options for a single call to BackupEngine::create_new_backup_with_options or BackupEngine::create_new_backup_with_metadata.
RestoreOptions
ShareFilesNaming
Naming scheme for table and blob files in the shared_checksum directory.

Enums

CpuPriority
CPU priority for the background threads that copy files during a backup.
RestoreMode
How much of the destination database a restore may reuse.