#[repr(i32)]pub enum PerfStatsLevel {
Uninitialized = 0,
Disable = 1,
EnableCount = 2,
EnableWait = 3,
EnableTimeExceptForMutex = 4,
EnableTimeAndCPUTimeExceptForMutex = 5,
EnableTime = 6,
OutOfBound = 7,
}Variants
Uninitialized = 0
Unknown settings
Disable = 1
Disable perf stats
EnableCount = 2
Enables only count stats
EnableWait = 3
Enables count stats and time spent waiting for RocksDB work
EnableTimeExceptForMutex = 4
Count stats and enable time stats except for mutexes
EnableTimeAndCPUTimeExceptForMutex = 5
Other than time, also measure CPU time counters. Still don’t measure time (neither wall time nor CPU time) for mutexes
EnableTime = 6
Enables count and time stats
OutOfBound = 7
N.B must always be the last value!