pub struct CompactOptions { /* private fields */ }Implementations
Sourceimpl CompactOptions
impl CompactOptions
Sourcepub fn set_exclusive_manual_compaction(&mut self, v: bool)
pub fn set_exclusive_manual_compaction(&mut self, v: bool)
If more than one thread calls manual compaction, only one will actually schedule it while the other threads will simply wait for the scheduled manual compaction to complete. If exclusive_manual_compaction is set to true, the call will disable scheduling of automatic compaction jobs and wait for existing automatic compaction jobs to finish.
Sourcepub fn set_bottommost_level_compaction(
&mut self,
lvl: BottommostLevelCompaction,
)
pub fn set_bottommost_level_compaction( &mut self, lvl: BottommostLevelCompaction, )
Sets bottommost level compaction.
Sourcepub fn set_change_level(&mut self, v: bool)
pub fn set_change_level(&mut self, v: bool)
If true, compacted files will be moved to the minimum level capable of holding the data or given level (specified non-negative target_level).
Sourcepub fn set_target_level(&mut self, lvl: c_int)
pub fn set_target_level(&mut self, lvl: c_int)
If change_level is true and target_level have non-negative value, compacted files will be moved to target_level.
Sourcepub fn set_full_history_ts_low<S: Into<Vec<u8>>>(&mut self, ts: S)
pub fn set_full_history_ts_low<S: Into<Vec<u8>>>(&mut self, ts: S)
Set user-defined timestamp low bound, the data with older timestamp than low bound maybe GCed by compaction. Default: nullptr
Sourcepub fn set_blob_garbage_collection_age_cutoff(&mut self, v: c_double)
pub fn set_blob_garbage_collection_age_cutoff(&mut self, v: c_double)
Override CompactRangeOptions::blob_garbage_collection_age_cutoff for a
single manual compaction.
If set to < 0 or > 1, RocksDB leaves the
blob_garbage_collection_age_cutoff from ColumnFamilyOptions in
effect (this is the default, -1). Otherwise, it overrides the
user-provided setting for the duration of this compaction. This
enables callers to selectively override the age cutoff per
compact_range call.
See Options::set_blob_gc_age_cutoff for the CF-level setter that
this value overrides.