SnapshotReadOptions

Struct SnapshotReadOptions 

pub struct SnapshotReadOptions<'snapshot, 'db, D: DBAccess = DB> { /* private fields */ }
Reusable read state bound to a SnapshotWithThreadMode.

Creating this value configures one native ReadOptions with the snapshot. Its get and multi-get methods reuse those options until the session is dropped. Custom options can be supplied with SnapshotWithThreadMode::read_options_opt.

The session cannot outlive its snapshot:

use rust_rocksdb::DB;

let db = DB::open_default("foo").unwrap();
let _read_options = {
    let snapshot = db.snapshot();
    snapshot.read_options()
};

Implementations

Source

impl<'db, D: DBAccess> SnapshotReadOptions<'_, 'db, D>

pub fn get<K: AsRef<[u8]>>(&self, key: K) -> Result<Option<Vec<u8>>, Error>

Returns the bytes associated with a key.

pub fn get_cf<K: AsRef<[u8]>>( &self, cf: &impl AsColumnFamilyRef, key: K, ) -> Result<Option<Vec<u8>>, Error>

Returns the bytes associated with a key in a column family.

pub fn get_pinned<K: AsRef<[u8]>>( &self, key: K, ) -> Result<Option<DBPinnableSlice<'db>>, Error>

Returns a pinned value associated with a key.

pub fn get_pinned_cf<K: AsRef<[u8]>>( &self, cf: &impl AsColumnFamilyRef, key: K, ) -> Result<Option<DBPinnableSlice<'db>>, Error>

Returns a pinned value associated with a key in a column family.

pub fn multi_get<K, I>(&self, keys: I) -> Vec<Result<Option<Vec<u8>>, Error>>
where K: AsRef<[u8]>, I: IntoIterator<Item = K>,

Returns the values associated with the given keys.

pub fn multi_get_cf<'b, K, I, W>( &self, keys_cf: I, ) -> Vec<Result<Option<Vec<u8>>, Error>>
where K: AsRef<[u8]>, I: IntoIterator<Item = (&'b W, K)>, W: AsColumnFamilyRef + 'b,

Returns the values associated with the given keys and column families.