pub struct WaitForCompactOptions { /* private fields */ }Implementations
Sourceimpl WaitForCompactOptions
impl WaitForCompactOptions
Sourcepub fn set_abort_on_pause(&mut self, v: bool)
pub fn set_abort_on_pause(&mut self, v: bool)
If true, abort waiting if background jobs are paused. If false, ContinueBackgroundWork() must be called to resume the background jobs. Otherwise, jobs that were queued, but not scheduled yet may never finish and WaitForCompact() may wait indefinitely (if timeout is set, it will abort after the timeout).
Default: false
Sourcepub fn set_flush(&mut self, v: bool)
pub fn set_flush(&mut self, v: bool)
If true, flush all column families before starting to wait.
Default: false
Sourcepub fn set_timeout(&mut self, microseconds: u64)
pub fn set_timeout(&mut self, microseconds: u64)
Timeout in microseconds for waiting for compaction to complete. when timeout == 0, WaitForCompact() will wait as long as there’s background work to finish.
Default: 0
Sourcepub fn set_wait_for_purge(&mut self, val: bool)
pub fn set_wait_for_purge(&mut self, val: bool)
A boolean to wait for purge to complete
Sourcepub fn get_wait_for_purge(&self) -> bool
pub fn get_wait_for_purge(&self) -> bool
Returns the value of the wait_for_purge option.
Sourcepub fn get_abort_on_pause(&self) -> bool
pub fn get_abort_on_pause(&self) -> bool
Returns the current abort_on_pause setting.
See Self::set_abort_on_pause for what this controls.
Sourcepub fn get_close_db(&self) -> bool
pub fn get_close_db(&self) -> bool
Returns the current close_db setting.
See Self::set_close_db for what this controls.
Sourcepub fn get_flush(&self) -> bool
pub fn get_flush(&self) -> bool
Returns the current flush setting.
See Self::set_flush for what this controls.
Sourcepub fn get_timeout(&self) -> u64
pub fn get_timeout(&self) -> u64
Returns the current timeout setting.
See Self::set_timeout for what this controls.
Sourcepub fn set_close_db(&mut self, val: bool)
pub fn set_close_db(&mut self, val: bool)
A boolean to call Close() after waiting is done. By the time Close() is called here, there should be no background jobs in progress and no new background jobs should be added. DB may not have been closed if Close() returned Aborted status due to unreleased snapshots in the system. See comments in DB::Close() for details.