pub struct WriteOptions { /* private fields */ }Expand description
Optionally disable WAL or sync for this write.
Examples
Making an unsafe write of a batch:
use rust_rocksdb::{DB, Options, WriteBatch, WriteOptions};
let tempdir = tempfile::Builder::new()
.prefix("_path_for_rocksdb_storageY1")
.tempdir()
.expect("Failed to create temporary path for the _path_for_rocksdb_storageY1");
let path = tempdir.path();
{
let db = DB::open_default(path).unwrap();
let mut batch = WriteBatch::default();
batch.put(b"my key", b"my value");
batch.put(b"key2", b"value2");
batch.put(b"key3", b"value3");
let mut write_options = WriteOptions::default();
write_options.set_sync(false);
write_options.disable_wal(true);
db.write_opt(&batch, &write_options);
}
let _ = DB::destroy(&Options::default(), path);Implementations
Sourceimpl WriteOptions
impl WriteOptions
pub fn new() -> WriteOptions
Sourcepub fn set_sync(&mut self, sync: bool)
pub fn set_sync(&mut self, sync: bool)
Sets the sync mode. If true, the write will be flushed from the operating system buffer cache before the write is considered complete. If this flag is true, writes will be slower.
Default: false
Sourcepub fn disable_wal(&mut self, disable: bool)
pub fn disable_wal(&mut self, disable: bool)
Sets whether WAL should be active or not. If true, writes will not first go to the write ahead log, and the write may got lost after a crash.
Default: false
Sourcepub fn set_ignore_missing_column_families(&mut self, ignore: bool)
pub fn set_ignore_missing_column_families(&mut self, ignore: bool)
If true and if user is trying to write to column families that don’t exist (they were dropped), ignore the write (don’t return an error). If there are multiple writes in a WriteBatch, other writes will succeed.
Default: false
Sourcepub fn set_no_slowdown(&mut self, no_slowdown: bool)
pub fn set_no_slowdown(&mut self, no_slowdown: bool)
If true and we need to wait or sleep for the write request, fails immediately with Status::Incomplete().
Default: false
Sourcepub fn set_low_pri(&mut self, v: bool)
pub fn set_low_pri(&mut self, v: bool)
If true, this write request is of lower priority if compaction is behind. In this case, no_slowdown = true, the request will be cancelled immediately with Status::Incomplete() returned. Otherwise, it will be slowed down. The slowdown value is determined by RocksDB to guarantee it introduces minimum impacts to high priority writes.
Default: false
Sourcepub fn set_memtable_insert_hint_per_batch(&mut self, v: bool)
pub fn set_memtable_insert_hint_per_batch(&mut self, v: bool)
If true, writebatch will maintain the last insert positions of each memtable as hints in concurrent write. It can improve write performance in concurrent writes if keys in one writebatch are sequential. In non-concurrent writes (when concurrent_memtable_writes is false) this option will be ignored.
Default: false
Sourcepub fn set_io_activity(&mut self, val: c_int)
pub fn set_io_activity(&mut self, val: c_int)
EXPERIMENTAL
Sourcepub fn get_io_activity(&self) -> c_int
pub fn get_io_activity(&self) -> c_int
Returns the value of the io_activity option.
Sourcepub fn set_protection_bytes_per_key(&mut self, val: usize)
pub fn set_protection_bytes_per_key(&mut self, val: usize)
protection_bytes_per_key is the number of bytes used to store protection information
for each key entry. Currently supported values are zero (disabled) and eight.
Default: zero (disabled).
Sourcepub fn get_protection_bytes_per_key(&self) -> usize
pub fn get_protection_bytes_per_key(&self) -> usize
Returns the value of the protection_bytes_per_key option.
Sourcepub fn set_rate_limiter_priority(&mut self, val: c_int)
pub fn set_rate_limiter_priority(&mut self, val: c_int)
For file reads associated with this option, charge the internal rate limiter (see
DBOptions::rate_limiter) at the specified priority. The special value
Env::IO_TOTAL disables charging the rate limiter.
The rate limiting is bypassed no matter this option’s value for file reads on plain
tables (these can exist when ColumnFamilyOptions::table_factory is a
PlainTableFactory) and cuckoo tables (these can exist when
ColumnFamilyOptions::table_factory is a CuckooTableFactory).
The bytes charged to rate limiter may not exactly match the file read bytes since there are some seemingly insignificant reads, like for file headers/footers, that we currently do not charge to rate limiter.
Sourcepub fn get_rate_limiter_priority(&self) -> c_int
pub fn get_rate_limiter_priority(&self) -> c_int
Returns the value of the rate_limiter_priority option.
Sourcepub fn get_disable_wal(&self) -> bool
pub fn get_disable_wal(&self) -> bool
Returns the current disable_wal setting.
See Self::disable_wal for what this controls.
Sourcepub fn get_ignore_missing_column_families(&self) -> bool
pub fn get_ignore_missing_column_families(&self) -> bool
Returns the current ignore_missing_column_families setting.
See Self::set_ignore_missing_column_families for what this controls.
Sourcepub fn get_low_pri(&self) -> bool
pub fn get_low_pri(&self) -> bool
Returns the current low_pri setting.
See Self::set_low_pri for what this controls.
Sourcepub fn get_memtable_insert_hint_per_batch(&self) -> bool
pub fn get_memtable_insert_hint_per_batch(&self) -> bool
Returns the current memtable_insert_hint_per_batch setting.
See Self::set_memtable_insert_hint_per_batch for what this controls.
Sourcepub fn get_no_slowdown(&self) -> bool
pub fn get_no_slowdown(&self) -> bool
Returns the current no_slowdown setting.
See Self::set_no_slowdown for what this controls.
Sourcepub fn get_sync(&self) -> bool
pub fn get_sync(&self) -> bool
Returns the current sync setting.
See Self::set_sync for what this controls.