pub trait WriteBatchIterator {
// Required methods
fn put(&mut self, key: &[u8], value: &[u8]);
fn delete(&mut self, key: &[u8]);
}Expand description
Receives the puts and deletes of a write batch.
The application must provide an implementation of this trait when
iterating the operations within a WriteBatch
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".